#Mechanical Constants
g = 9.81  # Acceleration due to gravity (m/s²)
ATM_PRESSURE = 101325  # Atmospheric pressure at sea level (Pa)
WATER_DENSITY = 1000  # Density of water (kg/m³)
AIR_DENSITY = 1.225  # Density of air at sea level (kg/m³)
STEEL_DENSITY = 7850  # Density of steel (kg/m³)
ALUMINUM_DENSITY = 2700  # Density of aluminum (kg/m³)
BRASS_DENSITY = 8500  # Density of brass (kg/m³)
CAST_IRON_DENSITY = 7200  # Density of cast iron (kg/m³)


#Geometric Constants
PI = 3.14159  # Pi (π)
GOLDEN_RATIO = 1.618  # The golden ratio (φ)

#Material Properties
YOUNGS_MODULUS_STEEL = 2.0e11  # Young's modulus for steel (Pa)
YOUNGS_MODULUS_ALUMINUM = 6.9e10  # Young's modulus for aluminum (Pa)
POISSON_RATIO_STEEL = 0.3  # Poisson's ratio for steel
POISSON_RATIO_ALUMINUM = 0.33  # Poisson's ratio for aluminum

#Thermodynamics Constants
BOLTZMANN_CONSTANT = 1.38e-23  # Boltzmann constant (J/K)
UNIVERSAL_GAS_CONSTANT = 8.314  # Universal gas constant (J/(mol·K))
STEFAN_BOLTZMANN_CONSTANT = 5.67e-8  # Stefan-Boltzmann constant (W/m²·K⁴)
SPECIFIC_HEAT_WATER = 4186  # Specific heat capacity of water (J/(kg·K))
SPECIFIC_HEAT_AIR = 1005  # Specific heat capacity of air (J/(kg·K))
LATENT_HEAT_WATER = 2.26e6  # Latent heat of vaporization of water (J/kg)
THERMAL_EXPANSION_STEEL = 1.2e-5  # Linear thermal expansion coefficient of steel (1/K)

#Friction and Incline
COEFF_FRICTION_STEEL = 0.74  # Typical coefficient of static friction for steel on steel
COEFF_FRICTION_WOOD = 0.40  # Typical coefficient of static friction for wood on wood
COEFF_FRICTION_RUBBER = 1.0  # Coefficient of friction (rubber on concrete)


#Energy and power
SPEED_OF_LIGHT = 299792458  # Speed of light in a vacuum (m/s)
PLANCK_CONSTANT = 6.626e-34  # Planck's constant (J·s)
HEAT_CAPACITY_RATIO_AIR = 1.4  # Specific heat ratio (Cp/Cv) for air

#Fluid mechanics
WATER_DENSITY = 1000  # Density of water (kg/m³)
AIR_DENSITY = 1.225  # Density of air at sea level (kg/m³)
KINEMATIC_VISCOSITY_WATER = 1e-6  # Kinematic viscosity of water (m²/s)
KINEMATIC_VISCOSITY_AIR = 1.5e-5  # Kinematic viscosity of air (m²/s)
SURFACE_TENSION_WATER = 0.072  # Surface tension of water at 20°C (N/m)
DYNAMIC_VISCOSITY_WATER = 0.001  # Dynamic viscosity of water (Pa·s)
DYNAMIC_VISCOSITY_AIR = 1.81e-5  # Dynamic viscosity of air (Pa·s)
GRAVITY_CONSTANT = 9.81  # Gravitational constant (m/s²)